Crate crabtrap

This crate provides a single function started_by_explorer

started_by_explorer can be used to check if a windows executable was launched by double clicking on the executable or from “PowerToys Run” or, instead, if it was launched from the terminal

Functions

started_by_explorer
returns bool: on systems different from Windows this function always returns false open an issue with a proposal if you are interested in the feature